@@ -1,13 +1,13 @@
 # LLNG wrapper class to enable AuthBasic handler with auto-protected PSGI
 #
-# See http://lemonldap-ng.org/documentation/latest/handlerarch
-package Lemonldap::NG::Handler::Server::AuthBasic;
+# See https://lemonldap-ng.org/documentation/latest/handlerarch
+package Lemonldap::NG::Handler::PSGI::AuthBasic;
 
 use strict;
 
 use base 'Lemonldap::NG::Handler::Lib::AuthBasic',
   'Lemonldap::NG::Handler::PSGI::Main';
 
-our $VERSION = '1.9.991_01';
+our $VERSION = '2.0.0';
 
 1;
